# Components - Salt States
- [chrony](#chrony)
 - [dnsmasq](#dnsmasq)
 - [docker](#docker)
 - [firewalld](#firewalld)
 - [hostapd](#hostapd)
 - [hosts](#hosts)
 - [mariadb](#mariadb)
 - [nfs-server](#nfs-server)
 - [nginx](#nginx)
 - [packages](#packages)
 - [podman](#podman)
 - [pxe](#pxe)
 - [rancher](#rancher)
 - [remote-desktop](#remote-desktop)
 - [rmt](#rmt)
 - [ssh](#ssh)
 - [tlu-harvester](#tlu-harvester)
 - [vlan](#vlan)
 - [wol](#wol)

## chrony
Chrony is an implementation of the Network Time Protocol (NTP).
This step will install chrony and configure upstream pools and start serving NTP on internal networks
```
# salt/pillars/chrony.sls
chrony:
  pool:
    - 0.se.pool.ntp.org
    - 1.se.pool.ntp.org
    - 2.se.pool.ntp.org
    - 3.se.pool.ntp.org
```

## dnsmasq
Serves dhcp and dns for internal network
This step will install dnsmasq and configure dhcp for all internal networks defined in `salt/pillars/network.sls`
It will also configure the pxe next step, etc.

## docker
This step will create podman container running a local docker registry pull through instance, also a systemd service called `registry-container.service` is created.
```
# salt/pillars/docker.sls
docker:
  username:
  access_token:
  url: docker.io/registry
  tag: 2.7.1
```

## firewalld
Configures firewalld services and networks

<a name="hostapd"/>
Installs and configures hostapd to use the wireless interface as a access point
```
# salt/pillars/hostapd.sls
hostapd:
  country_code: SE
  ssid: Transportable Lab Unit
  channel: 6
  wpa_passphrase: linux2linux
```

## hosts
Configures the hostname and `/etc/hosts` file so [dnsmasq](#dnsmasq) has correct information

### mariadb
Installs and configures mariadb, [rmt](#rmt) needs a database
```
# salt/pillars/mysql.sls
mysql:
  root_password: linux
```

## nfs-server
